@@ -5,15 +5,18 @@ use tendermint_light_client::{
     components::{
         io::{AtHeight, Io},
         scheduler,
-        verifier::ProdVerifier,
     },
     errors::Error,
-    light_client::{LightClient, Options},
-    operations::ProdHasher,
+    light_client::LightClient,
     state::State,
     store::{memory::MemoryStore, LightStore},
     tests::*,
-    types::{LightBlock, Status},
+    verifier::{
+        operations::ProdHasher,
+        options::Options,
+        types::{LightBlock, Status},
+        ProdVerifier,
+    },
 };
 
 use tendermint_testgen::light_block::default_peer_id;
